<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Faq_Builder_Ays
 * @subpackage Faq_Builder_Ays/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Faq_Builder_Ays
 * @subpackage Faq_Builder_Ays/admin
 * @author     F.A.Q Builder Team <info@ays-pro.com>
 */
class Faq_Builder_Ays_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;
    
    private $faqs_object;
    private $settings_obj;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
        add_filter('set-screen-option', array(__CLASS__, 'set_screen'), 10, 3);
	}

    public function admin_menu_styles(){
        
        echo "<style>
                #adminmenu a.toplevel_page_faq-builder-ays div.wp-menu-image img {
                    width: 32px;
                    padding: 1px 0 0;
                }
            <style>";

    }

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles($hook_suffix) {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Faq_Builder_Ays_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Faq_Builder_Ays_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_style('sweetalert-css', '//cdn.jsdelivr.net/npm/sweetalert2@7.26.29/dist/sweetalert2.min.css', array(), $this->version, 'all');

        wp_enqueue_style($this->plugin_name . '-admin', plugin_dir_url(__FILE__) . 'css/admin.css', array(), $this->version, 'all');
    
        wp_enqueue_style($this->plugin_name . "-banner", plugin_dir_url(__FILE__) . 'css/faq-builder-ays-banner.css', array(), time()/*$this->version*/, 'all');

        if (false === strpos($hook_suffix, $this->plugin_name))
            return;
    
        wp_enqueue_style('wp-color-picker');
        wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/faq-builder-ays-admin.css', array(), $this->version, 'all' );
        wp_enqueue_style('ays_faq_font_awesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css', array(), $this->version, 'all');
        wp_enqueue_style('ays_faq_bootstrap', plugin_dir_url(__FILE__) . 'css/bootstrap.min.css', array(), $this->version, 'all');
        wp_enqueue_style('ays-qm-select2', '//cdnjs.cloudflare.com/ajax/libs/select2/4.0.0/css/select2.min.css', array(), $this->version, 'all');
        wp_enqueue_style('ays-datatable', '//cdn.datatables.net/1.10.19/css/jquery.dataTables.css', array(), $this->version, 'all');
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/faq-builder-ays-admin.css', array(), time()/*$this->version*/, 'all');

        wp_enqueue_style('ays_code_mirror', 'https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.48.4/codemirror.css', array(), $this->version, 'all');
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts($hook_suffix) {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Faq_Builder_Ays_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Faq_Builder_Ays_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        if (false !== strpos($hook_suffix, "plugins.php")){
            wp_enqueue_script( 'sweetalert-js', '//cdn.jsdelivr.net/npm/sweetalert2@7.26.29/dist/sweetalert2.all.min.js', array('jquery'), $this->version, true );
            wp_enqueue_script($this->plugin_name . '-admin', plugin_dir_url(__FILE__) . 'js/admin.js', array('jquery'), $this->version, true);
            wp_localize_script($this->plugin_name . '-admin',  'faq_admin_ajax', array('ajax_url' => admin_url('admin-ajax.php')));
        }

        wp_enqueue_script( $this->plugin_name . "-banner", plugin_dir_url(__FILE__) . 'js/faq-builder-ays-banner.js', array('jquery'), $this->version, true);

        if(false === strpos($hook_suffix, $this->plugin_name))
            return;     
        
        wp_enqueue_script('jquery');
        wp_enqueue_script( 'jquery-ui-sortable' );
        
        wp_enqueue_script( "ays_pb_popper", 'https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.3/umd/popper.min.js', array( 'jquery' ), $this->version, true );
        wp_enqueue_script( 'select2js', '//cdnjs.cloudflare.com/ajax/libs/select2/4.0.6-rc.0/js/select2.min.js', array('jquery'), $this->version, true );
		wp_enqueue_script( "ays_pb_bootstrap", 'https://stackpath.bootstrapcdn.com/bootstrap/4.1.3/js/bootstrap.min.js', array( 'jquery' ), $this->version, true );
        /*wp_enqueue_script( 'iris', plugin_dir_url(__FILE__) . admin_url( 'js/iris.min.js' ), array( 'jquery-ui-draggable', 'jquery-ui-slider', 'jquery-touch-punch' ), false, 1 );*/
        wp_enqueue_script( $this->plugin_name, plugin_dir_url(__FILE__) . 'js/faq-builder-ays-admin.js', array('jquery', 'wp-color-picker'), $this->version, true);
        
        wp_localize_script($this->plugin_name,  'faq_admin_ajax', array('ajax_url' => admin_url('admin-ajax.php')));
        wp_enqueue_script( $this->plugin_name . '-color-picker-alpha', plugin_dir_url(__FILE__) . 'js/wp-color-picker-alpha.min.js', array( 'wp-color-picker' ), $this->version, true );
        $color_picker_strings = array(
            'clear'            => __( 'Clear', $this->plugin_name ),
            'clearAriaLabel'   => __( 'Clear color', $this->plugin_name ),
            'defaultString'    => __( 'Default', $this->plugin_name ),
            'defaultAriaLabel' => __( 'Select default color', $this->plugin_name ),
            'pick'             => __( 'Select Color', $this->plugin_name ),
            'defaultLabel'     => __( 'Color value', $this->plugin_name ),
        );
        wp_localize_script( $this->plugin_name . '-color-picker-alpha', 'wpColorPickerL10n', $color_picker_strings );
        wp_localize_script( $this->plugin_name, 'faqLangObj', array(
            'questionTitle' => __( 'Question Default Title', $this->plugin_name),
            'radio'         => __( 'Radio', $this->plugin_name),
            'checkbox'      => __( 'Checkbox', $this->plugin_name),
            'dropdawn'      => __( 'Dropdawn', $this->plugin_name),
            'emptyAnswer'   => __( 'Empty Answer', $this->plugin_name),
            'addGif'        => __( 'Add Gif', $this->plugin_name),
            'textType'      => __( 'Text', $this->plugin_name),
            'answerText'    => __( 'Answer text', $this->plugin_name),
            'copied'        => __( 'Copied!', $this->plugin_name),
            'clickForCopy'  => __( 'Click for copy.', $this->plugin_name),
        ) );

	}
    public function add_action_links($links){
        /*
        *  Documentation : https://codex.wordpress.org/Plugin_API/Filter_Reference/plugin_action_links_(plugin_file_name)
        */
        $text = __('Settings', $this->plugin_name);
        $settings_link = array(
            '<a href="' . admin_url('admin.php?page=' . $this->plugin_name) . '">' . $text . '</a>',
            '<a href="https://plugins.ays-demo.com/faq-builder-free-demo/" target="_blank">' . __('Demo', $this->plugin_name) . '</a>',
            '<a href="https://ays-pro.com/wordpress/faq-builder/" target="_blank" style="color:red;font-weight:bold;">' . __('Buy Now', $this->plugin_name) . '</a>',
            );
        return array_merge($settings_link, $links);

    }

      // Code Mirror

        function codemirror_enqueue_scripts($hook) {
        if (false === strpos($hook, $this->plugin_name)){
            return;
        }
        if(function_exists('wp_enqueue_code_editor')){
            $cm_settings['codeEditor'] = wp_enqueue_code_editor(array(
                'type' => 'text/css',
                'codemirror' => array(
                    'inputStyle' => 'contenteditable',
                    'theme' => 'cobalt',
                   
                )
            ));

            wp_enqueue_script('wp-theme-plugin-editor');
            wp_localize_script('wp-theme-plugin-editor', 'cm_settings', $cm_settings);
        
            wp_enqueue_style('wp-codemirror');
        }
    }
    
    /**
     * Register the administration menu for this plugin into the WordPress Dashboard menu.
     *
     * @since    1.0.0
     */
    
    public function add_plugin_admin_menu() {
        /*
         * Add a settings page for this plugin to the Settings menu.
         *
         * NOTE:  Alternative menu locations are available via WordPress administration menu functions.
         *
         *        Administration Menus: http://codex.wordpress.org/Administration_Menus
         *
         */
        
        $hook_faq = add_menu_page( __('F.A.Q. Builder', $this->plugin_name), __('F.A.Q. Builder', $this->plugin_name), 'manage_options', $this->plugin_name, array($this, 'display_plugin_setup_page'), AYS_FAQ_ADMIN_URL . 'images/faq-32x32.png', 6);
        
        add_action( "load-$hook_faq", array( $this, 'screen_option_faq' ) );
    }  

    public function add_plugin_faq_categories_submenu(){
        $hook_faq_categories = add_submenu_page(
            $this->plugin_name,
            __('F.A.Q. Categories', $this->plugin_name),
            __('F.A.Q. Categories', $this->plugin_name),
            'manage_options',
            $this->plugin_name . '-faq-categories',
            array($this, 'display_plugin_categories_page')
        );

    }
    public function add_plugin_general_settings_submenu(){
        $hook_faq_general_settings = add_submenu_page(
            $this->plugin_name,
            __('General Settings', $this->plugin_name),
            __('General Settings', $this->plugin_name),
            'manage_options',
            $this->plugin_name . '-faq-general-settings',
            array($this, 'display_plugin_general_settings')
        );
        $this->settings_obj = new FAQ_Settings_Actions($this->plugin_name);
    }
    public function add_plugin_faq_how_to_use_submenu(){
        $hook_faq_how_to_use = add_submenu_page(
            $this->plugin_name,
            __('How to use', $this->plugin_name),
            __('How to use', $this->plugin_name),
            'manage_options',
            $this->plugin_name . '-faq-how-to-use',
            array($this, 'display_plugin_how_to_use_page')
        );

    }   
    
    public function screen_option_faq() {
        $option = 'per_page';
        $args   = [
            'label'   => __('Show faqs per page', $this->plugin_name),
            'default' => 20,
            'option'  => 'faqs_per_page'
        ];

        add_screen_option( $option, $args );
        $this->faqs_object = new Faq_List_Table($this->plugin_name);
    }
    
    public function screen_option_settings(){
        $this->settings_obj = new FAQ_Settings_Actions($this->plugin_name);
    }

    public function display_plugin_setup_page() {
        $action = (isset($_GET['action'])) ? sanitize_text_field($_GET['action']) : '';

        switch ($action) {
            case 'add':
                include_once('partials/faq-builder-ays-admin-actions.php');
                break;
            case 'edit':
                include_once('partials/faq-builder-ays-admin-actions.php');
                break;
            default:
                include_once( 'partials/faq-builder-ays-admin-display.php' );
        }
    }
    public function display_plugin_categories_page(){
        include_once('partials/categories/faq-builder-ays-categories-display.php');
    }

    public function display_plugin_general_settings(){
        include_once('partials/settings/faq-builder-general-settings-display.php');
    }

    public function display_plugin_how_to_use_page(){
        include_once('partials/how-to-use/faq-builder-how-to-use.php');
    }

    public static function set_screen($status, $option, $value) {
        return $value;
    }

    public function deactivate_plugin_option(){
        $request_value = $_REQUEST['upgrade_plugin'];
        $upgrade_option = get_option('faq_ays_upgrade_plugin','');
        if($upgrade_option === ''){
            add_option('faq_ays_upgrade_plugin',$request_value);
        }else{
            update_option('faq_ays_upgrade_plugin',$request_value);
        }
        echo json_encode(array('option'=>get_option('faq_ays_upgrade_plugin','')));
        wp_die();
    }

    public static function ays_get_faq_user_question( $id ) {
	    global $wpdb;

        $sql = "SELECT user_question FROM {$wpdb->prefix}ays_faqs WHERE id=" . absint( intval( $id ) );

        $user_questions = array();
        $result = $wpdb->get_var($sql);
        if( ! is_null( $result ) ) {
            $user_questions = explode("****", $result); 
        }
        return $user_questions;
    }

    public function faq_admin_footer($a){
        if(isset($_REQUEST['page'])){
            if(false !== strpos($_REQUEST['page'], $this->plugin_name)){
                ?>
                <p style="font-size:13px;text-align:center;font-style:italic;">
                    <span style="margin-left:0px;margin-right:10px;" class="ays_heart_beat"><i class="fa fa-heart-o animated"></i></i></span>
                    <span><?php echo __( "If you love our plugin, please do big favor and rate us on", $this->plugin_name); ?></span> 
                    <a target="_blank" href='https://wordpress.org/support/plugin/faq-builder-ays/reviews/'>WordPress.org</a>
                    <span class="ays_heart_beat"><i class="fa fa-heart-o animated"></i></span>
                </p>
            <?php
            }
        }
    }

    public function ays_autoembed( $content ) {
        global $wp_embed;
        $content = stripslashes( wpautop( $content ) );
        $content = $wp_embed->autoembed( $content );
        if ( strpos( $content, '[embed]' ) !== false ) {
            $content = $wp_embed->run_shortcode( $content );
        }
        $content = do_shortcode( $content );
        return $content;
    }

    public function FAQ_live_preivew_content(){
        $content = isset($_REQUEST['content']) && $_REQUEST['content'] != '' ? wp_kses_post( $_REQUEST['content'] ) : null;

        if($content === null){
            echo json_encode(array(
                'status' => false,
            ));
            wp_die();
        }
        
        $content = $this->ays_autoembed( $content );

        echo json_encode(array(
            'status' => true,
            'content' => $content,
        ));

        wp_die();
    }

    /*
    ==========================================
        Sale Banner | Start
    ==========================================
    */

    public function ays_faq_sale_baner(){
        if (!isset($_GET['page']) || $_GET['page'] !== $this->plugin_name) return;
        if(isset($_POST['ays_faq_sale_btn'])){
            update_option('ays_faq_sale_notification', 1); 
            update_option('ays_faq_sale_date', current_time( 'mysql' ));
        }

        if(isset($_POST['ays_faq_sale_btn_for_two_months'])){
            update_option('ays_faq_sale_dismiss_for_two_month', 1);
            update_option('ays_faq_sale_date', current_time( 'mysql' ));
        }

        $ays_faq_sale_date = get_option('ays_faq_sale_date');
        $ays_faq_sale_two_months = get_option('ays_faq_sale_dismiss_for_two_month');

        $val = 60*60*24*5;
        if($ays_faq_sale_two_months == 1){
            $val = 60*60*24*61;
        }

        $ays_faq_sale_date = get_option('ays_faq_sale_date');
        $current_date = current_time( 'mysql' );
        $date_diff = strtotime($current_date) -  intval(strtotime($ays_faq_sale_date));

        $days_diff = $date_diff / $val;

        if(intval($days_diff) > 0 ){
            update_option('ays_faq_sale_notification', 0); 
            update_option('ays_faq_sale_dismiss_for_two_month', 0); 
        }

        $ays_faq_ishmar = intval(get_option('ays_faq_sale_notification'));
        $ays_faq_ishmar += intval(get_option('ays_faq_sale_dismiss_for_two_month'));
        if($ays_faq_ishmar == 0 ){
            // if (isset($_GET['page']) && strpos($_GET['page'], AYS_FAQ_NAME) !== false) {
            //     $this->ays_faq_sale_message($ays_faq_ishmar);
            // }
            // $this->ays_faq_winter_bundle_message($ays_faq_ishmar);
            $this->ays_faq_christmas_message($ays_faq_ishmar);
        }
    }


    public function ays_faq_sale_message($ishmar){
        if($ishmar == 0 ){
            $content = array();

            $content[] = '<div id="ays-faq-dicount-month-main" class="notice notice-success is-dismissible ays_faq_dicount_info">';
                $content[] = '<div id="ays-faq-dicount-month" class="ays_faq_dicount_month">';
                    $content[] = '<a href="https://ays-pro.com/business-bundle" target="_blank" class="ays-faq-sale-banner-link" style="display:none;"><img src="' . AYS_FAQ_ADMIN_URL . 'images/black-friday-great-bundle.png"></a>';

                    $content[] = '<div class="ays-faq-dicount-wrap-box">';

                        $content[] = '<strong style="font-weight: bold;">';
                            $content[] = __( "Limited Time <span class='ays-faq-dicount-wrap-color'>50%</span> SALE on <br><span><a href='https://ays-pro.com/business-bundle' target='_blank' class='ays-faq-dicount-wrap-color ays-faq-dicount-wrap-text-decoration' style='display:block;'>Business Bundle</a></span> (All 13 Plugins)!", AYS_FAQ_NAME );
                        $content[] = '</strong>';

                        $content[] = '<br>';

                        $content[] = '<strong>';
                                $content[] = __( "Hurry up! Ends on November 26. <a href='https://ays-pro.com/business-bundle' target='_blank'>Check it out!</a>", AYS_FAQ_NAME );
                        $content[] = '</strong>';
                            
                    $content[] = '</div>';

                    $content[] = '<div class="ays-faq-dicount-wrap-box">';

                        $content[] = '<div id="ays-faq-maker-countdown-main-container">';
                            $content[] = '<div class="ays-faq-maker-countdown-container">';

                                $content[] = '<div id="ays-faq-countdown">';
                                    $content[] = '<ul>';
                                        $content[] = '<li><span id="ays-faq-countdown-days"></span>days</li>';
                                        $content[] = '<li><span id="ays-faq-countdown-hours"></span>Hours</li>';
                                        $content[] = '<li><span id="ays-faq-countdown-minutes"></span>Minutes</li>';
                                        $content[] = '<li><span id="ays-faq-countdown-seconds"></span>Seconds</li>';
                                    $content[] = '</ul>';
                                $content[] = '</div>';

                                $content[] = '<div id="ays-faq-countdown-content" class="emoji">';
                                    $content[] = '<span>🚀</span>';
                                    $content[] = '<span>⌛</span>';
                                    $content[] = '<span>🔥</span>';
                                    $content[] = '<span>💣</span>';
                                $content[] = '</div>';

                            $content[] = '</div>';

                            $content[] = '<form action="" method="POST">';
                                $content[] = '<div id="ays-faq-dismiss-buttons-content">';
                                    $content[] = '<button class="btn btn-link ays-button" name="ays_faq_sale_btn_winter" style="height: 32px; margin-left: 0;padding-left: 0">Dismiss ad</button>';
                                    $content[] = '<button class="btn btn-link ays-button" name="ays_faq_sale_btn_winter_for_two_months" style="height: 32px; padding-left: 0">Dismiss ad for 2 months</button>';
                                $content[] = '</div>';
                            $content[] = '</form>';

                        $content[] = '</div>';
                            
                    $content[] = '</div>';

                    $content[] = '<div class="ays-faq-dicount-wrap-box ays-buy-now-button-box">';
                        $content[] = '<a href="https://ays-pro.com/business-bundle" class="button button-primary ays-buy-now-button" id="ays-button-top-buy-now" target="_blank" style="" >' . __( 'Buy Now !', AYS_FAQ_NAME ) . '</a>';
                    $content[] = '</div>';

                    $content[] = '<div class="ays-faq-dicount-wrap-box ays-faq-dicount-wrap-opacity-box">';
                        $content[] = '<a href="https://ays-pro.com/business-bundle" class="ays-buy-now-opacity-button" target="_blank">' . __( 'link', AYS_FAQ_NAME ) . '</a>';
                    $content[] = '</div>';

                $content[] = '</div>';
            $content[] = '</div>';

            $content = implode( '', $content );
            echo $content;
        }
    }

    // public function ays_faq_winter_bundle_message($flag){
    //     if($flag == 0 ){
    //         $content = array();
    //         $content[] = '<div id="ays-faq-dicount-month-main" class="notice notice-success is-dismissible ays_faq_dicount_info">';
    //             $content[] = '<div id="ays-faq-dicount-month" class="ays_faq_dicount_month">';
    //                 $content[] = '<a href="https://ays-pro.com/winter-bundle" target="_blank" class="ays-faq-sale-banner-link"><img src="' . AYS_FAQ_ADMIN_URL . 'images/winter_bundle_logo.png"></a>';

    //                 $content[] = '<div class="ays-faq-dicount-wrap-box">';

    //                     $content[] = '<strong>';
    //                         $content[] = __( "Limited Time <span class='ays-faq-dicount-wrap-color'>50%</span> SALE on <br><span><a href='https://ays-pro.com/winter-bundle' target='_blank' class='ays-faq-dicount-wrap-color ays-faq-dicount-wrap-text-decoration' style='display:block;'>Winter Bundle</a></span> (Copy + Popup + Survey)!", AYS_FAQ_NAME );
    //                     $content[] = '</strong>';

    //                     $content[] = '<br>';

    //                     $content[] = '<strong>';
    //                             $content[] = __( "Hurry up! Ends on January 1. <a href='https://ays-pro.com/winter-bundle' target='_blank'>Check it out!</a>", AYS_FAQ_NAME );
    //                     $content[] = '</strong>';
                            
    //                 $content[] = '</div>';

    //                 $content[] = '<div class="ays-faq-dicount-wrap-box">';

    //                     $content[] = '<div id="ays-faq-countdown-main-container">';
    //                         $content[] = '<div class="ays-faq-countdown-container">';

    //                             $content[] = '<div id="ays-faq-countdown">';
    //                                 $content[] = '<ul>';
    //                                     $content[] = '<li><span id="ays-faq-countdown-days"></span>days</li>';
    //                                     $content[] = '<li><span id="ays-faq-countdown-hours"></span>Hours</li>';
    //                                     $content[] = '<li><span id="ays-faq-countdown-minutes"></span>Minutes</li>';
    //                                     $content[] = '<li><span id="ays-faq-countdown-seconds"></span>Seconds</li>';
    //                                 $content[] = '</ul>';
    //                             $content[] = '</div>';

    //                             $content[] = '<div id="ays-faq-countdown-content" class="emoji">';
    //                                 $content[] = '<span>🚀</span>';
    //                                 $content[] = '<span>⌛</span>';
    //                                 $content[] = '<span>🔥</span>';
    //                                 $content[] = '<span>💣</span>';
    //                             $content[] = '</div>';

    //                         $content[] = '</div>';

    //                         $content[] = '<form action="" method="POST">';
	// 							$content[] ='<div id="ays-faq-dismiss-buttons-content" style="margin: auto;display:flex;">';
	// 								$content[] = '<button class="btn btn-link ays-button" name="ays_faq_sale_btn_winter" style="height: 32px; margin-left: 0;padding-left: 0;cursor:pointer;">Dismiss ad</button>';
	// 								$content[] = '<button class="btn btn-link ays-button" name="ays_faq_sale_btn_winter_for_two_months" style="height: 32px; padding-left: 0;margin-left:5px; cursor:pointer;">Dismiss ad for 2 months</button>';
	// 							$content[] ='</div>';
    //                         $content[] = '</form>';

    //                     $content[] = '</div>';
                            
    //                 $content[] = '</div>';

    //                 $content[] = '<a href="https://ays-pro.com/winter-bundle" class="button button-primary ays-button" id="ays-button-top-buy-now" target="_blank">' . __( 'Buy Now !', AYS_FAQ_NAME ) . '</a>';
    //             $content[] = '</div>';
    //         $content[] = '</div>';

    //         $content = implode( '', $content );
    //         echo $content;
    //     }
    // }

    // Christmas banner
    public static function ays_faq_christmas_message($ishmar){
        if($ishmar == 0 ){
            $content = array();

            $content[] = '<div id="ays-faq-dicount-christmas-month-main" class="notice notice-success is-dismissible ays_faq_dicount_info">';
                $content[] = '<div id="ays-faq-dicount-christmas-month" class="ays_faq_dicount_month">';
                    $content[] = '<div class="ays-faq-dicount-christmas-box">';
                        $content[] = '<div class="ays-faq-dicount-christmas-wrap-box ays-faq-dicount-christmas-wrap-box-80">';
                            $content[] = '<div class="ays-faq-dicount-christmas-title-row">' . __( 'Limited Time', AYS_FAQ_NAME ) .' '. '<a href="https://ays-pro.com/wordpress/faq-builder" class="ays-faq-dicount-christmas-button-sale" target="_blank">' . __( '20%', AYS_FAQ_NAME ) . '</a>' . ' SALE</div>';
                            $content[] = '<div class="ays-faq-dicount-christmas-title-row">' . __( 'FAQ Builder Plugin', AYS_FAQ_NAME ) . '</div>';
                        $content[] = '</div>';

                        $content[] = '<div class="ays-faq-dicount-christmas-wrap-box" style="width: 25%;">';
                            $content[] = '<div id="ays-faq-countdown-main-container">';
                                $content[] = '<div class="ays-faq-countdown-container">';
                                    $content[] = '<div id="ays-faq-countdown" style="display: block;">';
                                        $content[] = '<ul>';
                                            $content[] = '<li><span id="ays-faq-countdown-days"></span>' . __( 'Days', AYS_FAQ_NAME ) . '</li>';
                                            $content[] = '<li><span id="ays-faq-countdown-hours"></span>' . __( 'Hours', AYS_FAQ_NAME ) . '</li>';
                                            $content[] = '<li><span id="ays-faq-countdown-minutes"></span>' . __( 'Minutes', AYS_FAQ_NAME ) . '</li>';
                                            $content[] = '<li><span id="ays-faq-countdown-seconds"></span>' . __( 'Seconds', AYS_FAQ_NAME ) . '</li>';
                                        $content[] = '</ul>';
                                    $content[] = '</div>';
                                    $content[] = '<div id="ays-faq-countdown-content" class="emoji" style="display: none;">';
                                        $content[] = '<span>🚀</span>';
                                        $content[] = '<span>⌛</span>';
                                        $content[] = '<span>🔥</span>';
                                        $content[] = '<span>💣</span>';
                                    $content[] = '</div>';
                                $content[] = '</div>';
                            $content[] = '</div>';
                        $content[] = '</div>';

                        $content[] = '<div class="ays-faq-dicount-christmas-wrap-box" style="width: 25%;">';
                            $content[] = '<a href="https://ays-pro.com/wordpress/faq-builder" class="ays-faq-dicount-christmas-button-buy-now" target="_blank">' . __( 'BUY NOW!', AYS_FAQ_NAME ) . '</a>';
                        $content[] = '</div>';
                    $content[] = '</div>';
                $content[] = '</div>';

                $content[] = '<div style="position: absolute;right: 0;bottom: 1px;"  class="ays-faq-dismiss-buttons-container-for-form-christmas">';
                    $content[] = '<form action="" method="POST">';
                        $content[] = '<div id="ays-faq-dismiss-buttons-content-christmas">';
                            $content[] = '<button class="btn btn-link ays-button-christmas" name="ays_faq_sale_btn" style="">' . __( 'Dismiss ad', AYS_FAQ_NAME ) . '</button>';
                        $content[] = '</div>';
                    $content[] = '</form>';
                $content[] = '</div>';
            $content[] = '</div>';

            $content = implode( '', $content );

            echo $content;
        }
    }

    /*
    ==========================================
        Sale Banner | End
    ==========================================
    */
    public function get_next_or_prev_row_by_id( $id, $type = "next", $table = "ays_faqs" ) {
        global $wpdb;
        if ( is_null( $table ) || empty( $table ) ) {
            return null;
        }

        $ays_table = esc_sql( $wpdb->prefix . $table );

        $where = array();
        $where_condition = "";

        $id     = (isset( $id ) && $id != "" && absint($id) != 0) ? absint( sanitize_text_field( $id ) ) : null;
        $type   = (isset( $type ) && $type != "") ? sanitize_text_field( $type ) : "next";

        if ( is_null( $id ) || $id == 0 ) {
            return null;
        }

        switch ( $type ) {
            case 'prev':
                $where[] = ' `id` < ' . $id . ' ORDER BY `id` DESC ';
                break;
            case 'next':
            default:
                $where[] = ' `id` > ' . $id;
                break;
        }

        if( ! empty($where) ){
            $where_condition = " WHERE " . implode( " AND ", $where );
        }

        $sql = "SELECT `id` FROM {$ays_table} ". $where_condition ." LIMIT 1;";
        
        $results = $wpdb->get_row( $sql, 'ARRAY_A' );
        return $results;
    }

    public static function ays_restriction_string($type, $x, $length){
        $output = "";
        switch($type){
            case "char":                
                if(strlen($x)<=$length){
                    $output = $x;
                } else {
                    $output = substr($x,0,$length) . '...';
                }
                break;
            case "word":
                $res = explode(" ", $x);
                if(count($res)<=$length){
                    $output = implode(" ",$res);
                } else {
                    $res = array_slice($res,0,$length);
                    $output = implode(" ",$res) . '...';
                }
            break;
        }
        return $output;
    }

    public static function get_listtables_title_length( $listtable_name ) {
        global $wpdb;

        $settings_table = $wpdb->prefix . "ays_faq_settings";
        $sql = "SELECT meta_value FROM ".$settings_table." WHERE meta_key = 'options'";
        $result = $wpdb->get_var($sql);
        $options = ($result == "") ? array() : json_decode(stripcslashes($result), true);

        $listtable_title_length = 5;
        if(! empty($options) ){
            switch ( $listtable_name ) {
                case 'faq_title':
                    $listtable_title_length = (isset($options['faq_title_length']) && intval($options['faq_title_length']) != 0) ? absint(intval($options['faq_title_length'])) : 5;
                    break;   
                default:
                    $listtable_title_length = 5;
                    break;
            }
            return $listtable_title_length;
        }
        return $listtable_title_length;
    }

    public static function validateDate ($date, $format = 'Y-m-d H:i:s') {
        $d = DateTime::createFromFormat($format, $date);
        return $d && $d->format($format) == $date;
    }
}
