<?php
/**
 *  
 */
class FAQ_Settings_Actions {
    
    private $plugin_name;

    public function __construct($plugin_name) {
        $this->plugin_name = $plugin_name;
    }

    public function store_data(){
        global $wpdb;
        $settings_table = $wpdb->prefix . "ays_faq_settings";
        
        if( isset($_REQUEST["settings_action"]) && wp_verify_nonce( sanitize_text_field( $_REQUEST["settings_action"] ), 'settings_action' ) ){
            $success = 0;

            $faq_title_length = (isset($_REQUEST['ays_faq_title_length']) && intval($_REQUEST['ays_faq_title_length']) != 0) ? absint(intval($_REQUEST['ays_faq_title_length'])) : 5;

            // WP Editor height
            $faq_wp_editor_height = (isset($_REQUEST['ays_faq_wp_editor_height']) && $_REQUEST['ays_faq_wp_editor_height'] != '' && $_REQUEST['ays_faq_wp_editor_height'] != 0) ? absint( sanitize_text_field($_REQUEST['ays_faq_wp_editor_height']) ) : 100;
            $options = array(
                "faq_title_length" => $faq_title_length,
                "faq_wp_editor_height" => $faq_wp_editor_height,
            );
            
            $result = $this->ays_update_setting('options', json_encode($options));
            if ($result) {
                $success++;
            }
        }
    }
  
    public function check_settings_meta($metas){
        global $wpdb;
        $settings_table = $wpdb->prefix . "ays_faq_settings";
        foreach($metas as $meta_key){
            $sql = "SELECT COUNT(*) FROM ". esc_sql( $settings_table ) ." WHERE meta_key = '". esc_sql( sanitize_text_field( $meta_key ) )."'";
            $result = $wpdb->get_var($sql);
            if(intval($result) == 0){
                $this->ays_add_setting($meta_key, "", "", "");
            }
        }
        return false;
    }
    
    public function ays_get_setting($meta_key){
        global $wpdb;
        $settings_table = $wpdb->prefix . "ays_faq_settings";

        if($wpdb->get_var("SHOW TABLES LIKE '$settings_table'") != $settings_table) {
            return false;
        }
        
        $sql = "SELECT meta_value FROM ".$settings_table." WHERE meta_key = '".$meta_key."'";
        $result = $wpdb->get_var($sql);
        if($result != ""){
            return $result;
        }
        return false;
    }
    
    public function ays_add_setting($meta_key, $meta_value, $note = "", $options = ""){
        global $wpdb;
        $settings_table = $wpdb->prefix . "ays_faq_settings";
        $result = $wpdb->insert(
            $settings_table,
            array(
                'meta_key'    => esc_sql( $meta_key ),
                'meta_value'  => esc_sql( $meta_value ),
                'note'        => esc_sql( $note ),
                'options'     => esc_sql( $options )
            ),
            array( '%s', '%s', '%s', '%s' )
        );
        if($result >= 0){
            return true;
        }
        return false;
    }
    
    public function ays_update_setting($meta_key, $meta_value, $note = null, $options = null){
        global $wpdb;
        $settings_table = $wpdb->prefix . "ays_faq_settings";
        $value = array(
            'meta_value'  => esc_sql( $meta_value ),
        );
        $value_s = array( '%s' );
        if($note != null){
            $value['note'] = esc_sql( $note );
            $value_s[] = '%s';
        }
        if($options != null){
            $value['options'] = esc_sql( $options );
            $value_s[] = '%s';
        }
        $result = $wpdb->update(
            $settings_table,
            $value,
            array( 'meta_key' => esc_sql( $meta_key ) ),
            $value_s,
            array( '%s' )
        );
        if($result >= 0){
            return true;
        }
        return false;
    }
    
    public function ays_delete_setting($meta_key){
        global $wpdb;
        $settings_table = $wpdb->prefix . "ays_faq_settings";
        $wpdb->delete(
            $settings_table,
            array( 'meta_key' => esc_sql( $meta_key ) ),
            array( '%s' )
        );
    }

    public function faq_settings_notices($status){

        if ( empty( $status ) )
            return;

        if ( 'saved' == $status )
            $updated_message = esc_html( __( 'Changes saved.', $this->plugin_name ) );
        elseif ( 'updated' == $status )
            $updated_message = esc_html( __( 'Quiz attribute .', $this->plugin_name ) );
        elseif ( 'deleted' == $status )
            $updated_message = esc_html( __( 'Quiz attribute deleted.', $this->plugin_name ) );

        if ( empty( $updated_message ) )
            return;

        ?>
        <div class="notice notice-success is-dismissible">
            <p> <?php echo $updated_message; ?> </p>
        </div>
        <?php
    }
    
}
?>