<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Faq_Builder_Ays
 * @subpackage Faq_Builder_Ays/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Faq_Builder_Ays
 * @subpackage Faq_Builder_Ays/public
 * @author     F.A.Q Builder Team <info@ays-pro.com>
 */
class Faq_Builder_Ays_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
        add_shortcode( 'ays_faq', array($this, 'ays_generate_faq') );

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {       
	// 	*
	// 	 * This function is provided for demonstration purposes only.
	// 	 *
	// 	 * An instance of this class should be passed to the run() function
	// 	 * defined in Faq_Builder_Ays_Loader as all of the hooks are defined
	// 	 * in that particular class.
	// 	 *
	// 	 * The Faq_Builder_Ays_Loader will then create the relationship
	// 	 * between the defined hooks and the functions defined in this
	// 	 * class.
		wp_enqueue_style('ays_faq_font_awesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css', array(), $this->version, 'all');
       
             
	}

    public function enqueue_styles_early(){
         wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/faq-builder-ays-public.css', array(), $this->version, 'all' );
    }



    


	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Faq_Builder_Ays_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Faq_Builder_Ays_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        
            wp_enqueue_script('jquery'); 
            wp_enqueue_script( "ays_pb_bootstrap", 'https://stackpath.bootstrapcdn.com/bootstrap/4.1.3/js/bootstrap.min.js', array( 'jquery' ), $this->version, true );
            wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/faq-builder-ays-public.js', array( 'jquery' ), $this->version, true );
            /*wp_enqueue_script($this->plugin_name . '-ajax-public', plugin_dir_url(__FILE__) . 'js/quiz-maker-public-ajax.js', array('jquery'), $this->version, true);*/
            wp_localize_script( $this->plugin_name, 'faq_builder_ays_public', array('ajax_url' => admin_url('admin-ajax.php')));
        
	}
    // public function ays_detect_faq_shortcode(){
    //         global $wp_query;   

    //         $ays_posts = $wp_query->posts;

    //         $pattern = get_shortcode_regex();
    //         $pattern = "\[(\[?)(ays_faq)(?![\w-])([^\]\/]*(?:\/(?!\])[^\]\/]*)*?)(?:(\/)\]|\](?:([^\[]*+(?:\[(?!\/\2\])[^\[]*+)*+)\[\/\2\])?)(\]?)";

    //         // echo "<pre>";
    //         // echo "</pre>";
    //         foreach ( $ays_posts as $post ){
    //         echo $post->ID;            
    //             if ( preg_match_all( '/'. $pattern .'/s', $post->post_content, $matches )
    //                 && array_key_exists( 2, $matches )
    //                 && in_array( 'ays_faq', $matches[2] )
    //             ) {                    
    //                 $this->enqueue_styles();
    //                 $this->enqueue_scripts();
    //                 break; 
    //             }    
    //         }
    //     }

    public function ays_autoembed( $content ) {
        global $wp_embed;
        $content = stripslashes( wpautop( $content ) );
        $content = $wp_embed->autoembed( $content );
        if ( strpos( $content, '[embed]' ) !== false ) {
            $content = $wp_embed->run_shortcode( $content );
        }
        $content = do_shortcode( $content );
        return $content;
    }

    public function ays_generate_faq( $attr ){
        global $wpdb;
        ob_start();
        $id = ( isset($attr['id']) ) ? absint( intval( $attr['id'] ) ) : null;

        if (is_null($id)) {
            echo "<p class='wrong_shortcode_text' style='color:red;'>" . __('Wrong shortcode initialized', $this->plugin_name) . "</p>";
            return str_replace(array("\r\n", "\n", "\r"), '', ob_get_clean());
        }
        
        $faq = $this->ays_get_faq_by_id($id);
        if (!$faq) {
            echo "<p class='wrong_shortcode_text' style='color:red;'>" . __('Wrong shortcode initialized', $this->plugin_name) . "</p>";
            return str_replace(array("\r\n", "\n", "\r"), '', ob_get_clean());
        }

        $style = (isset($faq['style']) && !empty($faq['style'])) ? $faq['style'] : array();
        $options = (isset($faq['options']) && !empty($faq['options'])) ? $faq['options'] : array();

        $this->enqueue_styles();
        $this->enqueue_scripts();

        $questions = (isset($faq['questions']) && $faq['questions'] != '') ? $faq['questions'] : '';
        $answer = (isset($faq['answers']) && $faq['answers'] != '') ? $faq['answers'] : '';
     
        if(isset($questions) ){
            $faq_question_array = explode('***', $questions);    
        }

        if(isset($answer)){
            $faq_answer_array = explode('***', $answer);
        }

        $ays_faq_theme = isset($style['style_theme']) && $style['style_theme'] != '' ? sanitize_text_field($style['style_theme']) : "default_arrow";
        
        $ays_iconDir = isset($style['icon_direction']) && $style['icon_direction'] != '' ? sanitize_text_field($style['icon_direction']) : "after";
    
        $bgColor = isset($style['bgColor']) && $style['bgColor'] != '' ? sanitize_text_field($style['bgColor']) : "#f0f0f0";

        $bgColorQuest = isset($style['bgColorQuest']) && $style['bgColorQuest'] != '' ? sanitize_text_field($style['bgColorQuest']) : "#DFDDDD";

        $bgColorAnsw = isset($style['bgColorAnsw']) && $style['bgColorAnsw'] != '' ? sanitize_text_field($style['bgColorAnsw']) : "#DFDDDD";

        $titleBgColor = isset($style['titleBgColor']) && $style['titleBgColor'] != '' ? sanitize_text_field($style['titleBgColor']) : "#f9f9f9";
        
        $textColor = isset($style['textColor']) && $style['textColor'] != '' ? sanitize_text_field($style['textColor']) : "#000000";
        
        $questtextColor = isset($style['questtextColor']) && $style['questtextColor'] != '' ? sanitize_text_field($style['questtextColor']) : "#000000";

        $answertextColor = isset($style['answertextColor']) && $style['answertextColor'] != '' ? sanitize_text_field($style['answertextColor']) : "#000000";

        $questBorderRadius = isset($style['questBorderRadius']) && $style['questBorderRadius'] != '' ? absint($style['questBorderRadius']) : "0";

        $faqBorderRadius = isset($style['faqBorderRadius']) && $style['faqBorderRadius'] != '' ? absint($style['faqBorderRadius']) : "0";

        $questSpaceBetween = isset($style['questSpaceBetween']) && $style['questSpaceBetween'] != '' ? absint($style['questSpaceBetween']) : "0";

        $ansHeight = (isset($style['ansHeight']) && $style['ansHeight'] != '') ? absint($style['ansHeight']) : "auto";
        
        $faqWidth = isset($style['faqWidth']) && $style['faqWidth'] != '' ? absint($style['faqWidth']) : "0";

        $ays_faq_border_width = (isset($style['ays_faq_border_width']) && $style['ays_faq_border_width'] != '') ? absint($style['ays_faq_border_width']) : '0';

        $faqMobileWidth = isset($style['faqMobileWidth']) && $style['faqMobileWidth'] != '' ? absint($style['faqMobileWidth']) : "0";

        $ays_faq_border_style = (isset($style['ays_faq_border_style']) && $style['ays_faq_border_style'] != '') ? sanitize_text_field($style['ays_faq_border_style']) : 'solid';

        $ays_faq_border_color = (isset($style['ays_faq_border_color']) && $style['ays_faq_border_color'] != '') ? sanitize_text_field($style['ays_faq_border_color']) : '#ffffff';

        $customClass = (isset($style['customClass']) && $style['customClass'] != '') ? sanitize_text_field($style['customClass']) : '';

        $custom_css = (isset($style['customCss']) && $style['customCss'] != '') ? stripslashes ( htmlspecialchars_decode($style['customCss'])) : '';

        $ays_faq_quest_font_size = (isset($style['quest_font_size']) && $style['quest_font_size'] != '') ? absint($style['quest_font_size']) : '18';

        $ays_faq_title_check = (isset($style['ays_faq_show_title']) && $style['ays_faq_show_title'] != '') ? $style['ays_faq_show_title'] : 'on';

        $ays_faq_show_title = (isset($ays_faq_title_check) && $ays_faq_title_check == 'on') ? true : false;
        
        $ays_faq_desc_check = (isset($style['ays_faq_show_desc']) && $style['ays_faq_show_desc'] != '') ? $style['ays_faq_show_desc'] : 'on';

        $ays_faq_show_desc = (isset($ays_faq_desc_check) && $ays_faq_desc_check == 'on') ? true : false;

        $faq_answers_left_right_padding = (isset($style['answers_left_right_padding']) && $style['answers_left_right_padding'] != '') ? absint($style['answers_left_right_padding']) : '11';

        $faq_answers_top_bottom_padding = (isset($style['answers_top_bottom_padding']) && $style['answers_top_bottom_padding'] != '') ? absint($style['answers_top_bottom_padding']) : '11';

        $faq_questions_left_right_padding = (isset($style['questions_left_right_padding']) && $style['questions_left_right_padding'] != '') ? absint($style['questions_left_right_padding']) : '11';

        $faq_questions_top_bottom_padding = (isset($style['questions_top_bottom_padding']) && $style['questions_top_bottom_padding'] != '') ? absint($style['questions_top_bottom_padding']) : '11';

        // $ays_faq_quest_alignment = (isset($style['quest_alignment']) && $style['quest_alignment'] != '') ? sanitize_text_field($style['quest_alignment']) : 'left';

        $ays_faq_ans_font_size = (isset($style['answer_font_size']) && $style['answer_font_size'] != '') ? absint($style['answer_font_size']) : '16';

        //Title font size
        $ays_faq_title_font_size = (isset($style['title_font_size']) && $style['title_font_size'] != '') ? absint($style['title_font_size']) : '21';

        //Title transformation
        $ays_faq_title_transformation = (isset($style['title_transformation']) && $style['title_transformation'] != '') ? sanitize_text_field($style['title_transformation']) : 'none';

        $ays_faq_quest_height = (isset($style['question_height']) && $style['question_height'] != '') ? absint($style['question_height']) : 'auto';

        //Description font size
        $ays_faq_desc_font_size = (isset($style['desc_font_size']) && $style['desc_font_size'] != '') ? absint($style['desc_font_size']) : '16';

        $default_hover_bg_color = '';
        $default_hover_text_color = '';
        switch ($ays_faq_theme) {
            case 'simple':
                $default_hover_bg_color = '#ffffff';
                $default_hover_text_color = '#039ae2';
                break;
            case 'plusminus':
                $default_hover_bg_color = '#ffffff';
                $default_hover_text_color = '#000000';
                break;
            case 'default_arrow':
                $default_hover_bg_color = '#d0cece';
                $default_hover_text_color = '#000000';
                break;
            default:
                break;
        }
        
        $ays_faq_hover_active_text_color = (isset($style['hover_active_text_color']) && $style['hover_active_text_color'] != '') ? sanitize_text_field($style['hover_active_text_color']) : $default_hover_text_color;
    
        $ays_faq_hover_active_bg_color = (isset($style['hover_active_bg_color']) && $style['hover_active_bg_color'] != '') ? sanitize_text_field($style['hover_active_bg_color']) : $default_hover_bg_color;

        $ays_faq_display_all = (isset($options['display_all']) && $options['display_all'] != '') ? sanitize_text_field($options['display_all']) : 'no';

        //Question border options start

        //Border side
        $style['enable_questions_border'] = (isset($style['enable_questions_border']) && $style['enable_questions_border'] == 'on') ? 'on' : 'off';
        $ays_faq_enable_questions_border = (isset($style['enable_questions_border']) && $style['enable_questions_border'] == 'on') ? true : false;

        //Border side
        $ays_faq_quest_border_side = (isset($style['questions_border_side']) && $style['questions_border_side'] != '') ? sanitize_text_field($style['questions_border_side']) : 'none';

        //Border width
        $ays_faq_quest_border_width = (isset($style['questions_border_width']) && $style['questions_border_width'] != '') ? absint($style['questions_border_width']) : '0';

        //Border style
        $ays_faq_quest_border_style = (isset($style['questions_border_style']) && $style['questions_border_style'] != '') ? sanitize_text_field($style['questions_border_style']) : 'solid';

        //Border color
        $ays_faq_quest_border_color = (isset($style['questions_border_color']) && $style['questions_border_color'] != '') ? sanitize_text_field($style['questions_border_color']) : '#000000';

        //Question border options end

        // Show question numbering
		$show_question_numbering = (isset($options['show_question_numbering']) && sanitize_text_field( $options['show_question_numbering'] ) != '') ? sanitize_text_field( $options['show_question_numbering'] ) : 'none';


        // $ays_faq_quest_align_style = '';

        // switch ($ays_faq_quest_alignment) {
        //     case 'left':
        //         $ays_faq_quest_align_style = 'text-align:left';
        //         break;
        //     case 'center':
        //         $ays_faq_quest_align_style = 'text-align:center';
        //         break;
        //     case 'right':
        //         $ays_faq_quest_align_style = 'text-align:right';
        //         break;
            
        //     default:
        //         # code...
        //         break;
        // }

        $ays_faq_display_all_style = '';

        switch ($ays_faq_display_all) {
            case 'yes':
                $ays_faq_display_all_style = '#faq_'.$faq['id'].' .ays-answer{
                                                max-height:100%;
                                                display:block;
                                            }';

                break;
            case 'no':
                $ays_faq_display_all_style = '#faq_'.$faq['id'].' .ays-answer{
                                                display:none;
                                            }';
                break;
            case 'only_first':
                $ays_faq_display_all_style = '#faq_'.$faq['id'].' .ays-main>div:first-child .ays-answer{
                                                max-height:100%;
                                                display:block;
                                            }';
                break;
            default:
                break;
        }

        $faq_ans_height = '';
        if($ays_faq_quest_height == 'auto'){
            $faq_ans_height = 'auto';
        }else{
            $faq_ans_height = $ays_faq_quest_height.'px';
        }

        if($faqWidth == 0){
            $faqWidth = '100%';
        }else{
            $faqWidth = $faqWidth . 'px' ;
        }

        $ays_faq_title_display = '';
        if(!$ays_faq_show_title){
            $ays_faq_title_display = 'display:none';
        }else{
            $ays_faq_title_display = '';
        }

        $ays_faq_desc_display = '';
        if(!$ays_faq_show_desc){
            $ays_faq_desc_display = 'display:none';
        }else{
            $ays_faq_desc_display = '';
        }

        if($faqMobileWidth == 0){
            $faqMobileWidth = '100%';
        }else{
            $faqMobileWidth = $faqMobileWidth . 'px' ;
        }

        $faq_view = "<div class='ays-faq-main ". $customClass."'  id='faq_".$faq['id']."' data-id='".$faq['id']."'>";
        $faq_view .= "<input type='hidden' id='display_all_faq_".$faq['id']."' data-name='".$ays_faq_display_all."' data-theme='".$ays_faq_theme."'/>";
        $faq_view .= "<script>";
        $faq_view .= "(function( $ ) {
                            'use strict';
                            $(document).ready(function(){
                                var displayAll = $(document).find('#display_all_faq_".$faq['id']."').data('name');
                                var themeName = $(document).find('#display_all_faq_".$faq['id']."').data('theme');
                                var themeClassName;
                                switch (themeName) {
                                    case 'simple':
                                        themeClassName = 'opened-simple';
                                        break;
                                        case 'plusminus':
                                            themeClassName = 'opened-plusminus';
                                        break;
                                    case 'default_arrow':
                                        themeClassName = 'opened-default';
                                        break;
                                    default:
                                        break;
                                }   
                                
                                switch (displayAll) {
                                    case 'yes':
                                        $(document).find('#faq_".$faq['id']." .ays-sub-question').addClass('previous-answer');
                                        $(document).find('#faq_".$faq['id']." .ays-sub-question').addClass(themeClassName);
                                        break;
                                    case 'no':
                                        break;
                                    case 'only_first':
                                        $(document).find('#faq_".$faq['id']."').find('.ays-main').find('#question_block_0').find('.ays-sub-question').addClass('previous-answer');
                                        $(document).find('#faq_".$faq['id']."').find('.ays-main').find('#question_block_0').find('.ays-sub-question').addClass(themeClassName);
                                        break;
                                    default:
                                        break;
                                }
                            });
                        })( jQuery );
        ";
        $faq_view .= "</script>";
        $faq_view .= "<style>";
        if(isset($style['faqWidth'])){
            $faq_view .= "
                            #faq_".$faq['id']."{
                                width: $faqWidth;
                            } 
                        ";
        }
        if(isset($style['ays_faq_border_width'])){
            $faq_view .= "
                            #faq_".$faq['id']."{
                                border-width: {$style['ays_faq_border_width']}px;
                            } 
                        ";
        }       
        if(isset($style['ays_faq_border_style'])){
            $faq_view .= "
                            #faq_".$faq['id']."{
                                border-style: {$style['ays_faq_border_style']};
                            } 
                        ";
        }
        if(isset($style['ays_faq_border_color'])){
            $faq_view .= "
                            #faq_".$faq['id']."{
                                border-color: {$style['ays_faq_border_color']};
                            } 
                        ";
        }
        if(isset($style['bgColor'])){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-faq{
                                background-color:{$bgColor};
                            } 
                        ";
        }
        if(isset($style['faqBorderRadius'])){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-faq{
                               border-radius:{$faqBorderRadius}px;
                            } 
                        ";
        }
        if(isset($style['bgColorQuest'])){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-question{
                                background-color:{$bgColorQuest};
                            } 
                        ";
        }
        if(isset($style['bgColorAnsw'])){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-answer{
                                background-color:{$bgColorAnsw};
                            } 
                        ";
        }
        if(isset($style['titleBgColor'])){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-title{
                                background-color:{$titleBgColor};
                            } 
                        ";
        }

        $faq_view .= "
                        #faq_".$faq['id']." .ays-title{
                            text-transform: ".$ays_faq_title_transformation.";
                        } 
                    ";

        if(isset($style['textColor'])){
            $faq_view .= "
                            #faq_".$faq['id']."{
                                color:{$textColor};
                            }
                        ";
        }
        if(isset($style['questtextColor'])){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-sub-question, #faq_".$faq['id']." .ays-sub-question .ays_faq_label{
                                color:{$questtextColor};
                            }
                        ";
        }
        if(isset($style['questBorderRadius'])){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-question{
                                border-radius:{$questBorderRadius}px;
                            }
                        ";
        }
        if($faq_questions_left_right_padding != '' || $faq_questions_top_bottom_padding != '' ){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-question{
                                padding:".$faq_questions_top_bottom_padding."px ".$faq_questions_left_right_padding."px;
                            }
                        ";
        }
        
        if(isset($style['questSpaceBetween'])){
            $faq_view .= "
                             #faq_".$faq['id']." div.ays-border-default:not(:last-child){
                                margin-bottom:{$questSpaceBetween}px;
                            }
                        ";
        }
        if($ansHeight != '0'){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-answer{
                                height:{$ansHeight}px;
                                overflow: auto;
                            }
                        ";
        }else{
            $faq_view .= "
                #faq_".$faq['id']." .ays-answer{
                    height:auto;
                    overflow: auto;
                }
            ";
        }
        if($faq_answers_left_right_padding != '' || $faq_answers_top_bottom_padding != '' ){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-answer{
                                padding:".$faq_answers_top_bottom_padding."px ".$faq_answers_left_right_padding."px;
                            }
                        ";
        }
        if(isset($style['answertextColor'])){
            $faq_view .= "
                            #faq_".$faq['id']." .ays-answer{
                                color:{$answertextColor};
                            }
                        ";
        }
        $faq_view .= "             
                @media screen and (max-width: 768px){                    
                        #faq_".$faq['id']."{                               
                            width: ".$faqMobileWidth.";
                        }                                         
                }
        ";
        if(isset($style['customCss'])){
            $faq_view .= $custom_css;
        }
        if(isset($style['icon_direction']) && $style['icon_direction'] != "none" && isset($style["ays_faq_Icon"])){
            
            if($style["ays_faq_Icon"] == ''){
                $style["ays_faq_Icon"] = 'f13a,f139';
            }
            
            $icons = explode(",", $style["ays_faq_Icon"]); 

            $faq_view .= "
                            #faq_".$faq['id']." .ays-question-default .ays-sub-question::".$ays_iconDir."{
                                font-family: FontAwesome;
                                content: '\\".$icons[0]."';
                            }
                            
                            #faq_".$faq['id']." .ays-question-default .ays-sub-question.opened-default::".$ays_iconDir."{
                                font-family: FontAwesome;
                                content: '\\".$icons[1]."';
                            }
                            #faq_".$faq['id']." .ays-question-plusminus .ays-sub-question::".$ays_iconDir."{
                                font-family: FontAwesome;
                                content: '\\".$icons[0]."';
                            }
                            
                            #faq_".$faq['id']." .ays-question-plusminus .ays-sub-question.opened-plusminus::".$ays_iconDir."{
                                font-family: FontAwesome;
                                content: '\\".$icons[1]."';
                            }
                            #faq_".$faq['id']." .ays-question-simple .ays-sub-question::".$ays_iconDir."{
                                font-family: FontAwesome;
                                content: '\\".$icons[0]."';
                                color: ".$style['textColor'].";
                            }
                            
                            #faq_".$faq['id']." .ays-question-simple .ays-sub-question.opened-simple::".$ays_iconDir."{
                                font-family: FontAwesome;
                                content: '\\".$icons[1]."';
                                color: '".$style['textColor']."';
                            }
                            #faq_".$faq['id']." .ays-sub-question, #faq_".$faq['id']." .ays-sub-question .ays_faq_label{
                                font-size:".$ays_faq_quest_font_size."px;
                            }
                            #faq_".$faq['id']." .ays-description p{
                                font-size:".$ays_faq_desc_font_size."px;
                            }
                        ";
            
        }
        
        if($ays_iconDir == "before"){
            $faq_view .= "
                #faq_".$faq['id']." .ays-sub-question{
                    display:flex;
                }
                #faq_".$faq['id']." .ays-question-default .ays-sub-question::before{
                    margin-right:10px;
                }
                
                #faq_".$faq['id']." .ays-question-default .ays-sub-question.opened-default::before{
                    margin-right:10px;
                }
                #faq_".$faq['id']." .ays-question-plusminus .ays-sub-question::before{
                    margin-right:10px;
                }
                
                #faq_".$faq['id']." .ays-question-plusminus .ays-sub-question.opened-plusminus::before{
                    margin-right:10px;
                }
                #faq_".$faq['id']." .ays-question-simple .ays-sub-question::before{
                    margin-right:10px;
                }
                
                #faq_".$faq['id']." .ays-question-simple .ays-sub-question.opened-simple::before{
                    margin-right:10px;
                }
            ";
            
        }elseif ($ays_iconDir == "after") {
            $faq_view .= "
            #faq_".$faq['id']." .ays-sub-question{
                display:flex;
                justify-content:space-between;
            }
            #faq_".$faq['id']." .ays-question-default .ays-sub-question::after{
                margin-left:10px;
            }
            
            #faq_".$faq['id']." .ays-question-default .ays-sub-question.opened-default::after{
                margin-left:10px;
            }
            #faq_".$faq['id']." .ays-question-plusminus .ays-sub-question::after{
                margin-left:10px;
            }
            
            #faq_".$faq['id']." .ays-question-plusminus .ays-sub-question.opened-plusminus::after{
                margin-left:10px;
            }
            #faq_".$faq['id']." .ays-question-simple .ays-sub-question::after{
                margin-left:10px;
                
            }
            
            #faq_".$faq['id']." .ays-question-simple .ays-sub-question.opened-simple::after{
                margin-left:10px;
            }
        ";
        }elseif($ays_iconDir == "none"){
            $faq_view .= "
                #faq_".$faq['id']." .ays-sub-question, #faq_".$faq['id']." .ays-sub-question .ays_faq_label{
                    font-size:".$ays_faq_quest_font_size."px;
                }
            ";
        }

        if($ays_faq_enable_questions_border){
            switch ($ays_faq_quest_border_side) {
                case 'all_sides':
                    $faq_view .= "
                        #faq_".$faq['id']." .ays-faq-question-border{
                            border: {$ays_faq_quest_border_width}px {$ays_faq_quest_border_style} {$ays_faq_quest_border_color};
                        }
                    ";
                    break;
                case 'none':
                    $faq_view .= "
                        #faq_".$faq['id']." .ays-faq-question-border{
                            border:none;
                        }
                    ";
                    break;
                case 'top':
                    $faq_view .= "
                        #faq_".$faq['id']." .ays-faq-question-border{
                            border-top: {$ays_faq_quest_border_width}px {$ays_faq_quest_border_style} {$ays_faq_quest_border_color};
                        }
                    ";
                    break;
                case 'bottom':
                    $faq_view .= "
                        #faq_".$faq['id']." .ays-faq-question-border{
                            border-bottom: {$ays_faq_quest_border_width}px {$ays_faq_quest_border_style} {$ays_faq_quest_border_color};
                        }
                    ";
                    break;
                case 'left':
                    $faq_view .= "
                        #faq_".$faq['id']." .ays-faq-question-border{
                            border-left: {$ays_faq_quest_border_width}px {$ays_faq_quest_border_style} {$ays_faq_quest_border_color};
                        }
                    ";
                    break;
                case 'right':
                    $faq_view .= "
                        #faq_".$faq['id']." .ays-faq-question-border{
                            border-right: {$ays_faq_quest_border_width}px {$ays_faq_quest_border_style} {$ays_faq_quest_border_color};
                        }
                    ";
                    break;
                default:
                    break;
            }
        }

        $faq_view .= "
                    #faq_".$faq['id']." .ays-question.ays-question-default .ays-sub-question.opened-default{
                        background-color:{$ays_faq_hover_active_bg_color};
                    }

                    #faq_".$faq['id']." .ays-question.ays-question-plusminus .ays-sub-question.opened-plusminus{
                        background-color:{$ays_faq_hover_active_bg_color};
                    }

                    #faq_".$faq['id']." .ays-question.ays-question-simple .ays-sub-question.opened-simple{
                        background-color:{$ays_faq_hover_active_bg_color};
                    }
                    #faq_".$faq['id']." .ays-question.ays-question-default .ays-sub-question:hover{
                        background-color:{$ays_faq_hover_active_bg_color};
                    }

                    #faq_".$faq['id']." .ays-question.ays-question-plusminus .ays-sub-question:hover{
                        background-color:{$ays_faq_hover_active_bg_color};
                    }

                    #faq_".$faq['id']." .ays-question.ays-question-simple .ays-sub-question:hover{
                        background-color:{$ays_faq_hover_active_bg_color};
                    }
                    #faq_".$faq['id']." .ays-question.ays-question-default .ays-sub-question.opened-default label{
                        color:{$ays_faq_hover_active_text_color};
                        
                    }

                    #faq_".$faq['id']." .ays-question.ays-question-plusminus .ays-sub-question.opened-plusminus label{
                        color:{$ays_faq_hover_active_text_color};
                        
                    }

                    #faq_".$faq['id']." .ays-question.ays-question-simple .ays-sub-question.opened-simple label{
                        color:{$ays_faq_hover_active_text_color};
                        
                    }
                    #faq_".$faq['id']." .ays-question.ays-question-default .ays-sub-question:hover label{
                        color:{$ays_faq_hover_active_text_color};
                        
                    }

                    #faq_".$faq['id']." .ays-question.ays-question-plusminus .ays-sub-question:hover label{
                        color:{$ays_faq_hover_active_text_color};
                        
                    }

                    #faq_".$faq['id']." .ays-question.ays-question-simple .ays-sub-question:hover label{
                        color:{$ays_faq_hover_active_text_color};
                        
                    }

                    #faq_".$faq['id']." .ays-question.ays-question-default .ays-sub-question.opened-default::{$ays_iconDir}{ 
                        color:{$ays_faq_hover_active_text_color};
                    }

                    #faq_".$faq['id']." .ays-question.ays-question-plusminus .ays-sub-question.opened-plusminus::{$ays_iconDir}{
                        color:{$ays_faq_hover_active_text_color};
                    }

                    #faq_".$faq['id']." .ays-question.ays-question-simple .ays-sub-question.opened-simple::{$ays_iconDir}{
                        color:{$ays_faq_hover_active_text_color};
                    }
                    #faq_".$faq['id']." .ays-question.ays-question-default .ays-sub-question:hover::{$ays_iconDir}{
                        color:{$ays_faq_hover_active_text_color};
                    }

                    #faq_".$faq['id']." .ays-question.ays-question-plusminus .ays-sub-question:hover::{$ays_iconDir}{
                        color:{$ays_faq_hover_active_text_color};
                    }

                    #faq_".$faq['id']." .ays-question.ays-question.ays-question-simple .ays-sub-question:hover::{$ays_iconDir}{
                        color:{$ays_faq_hover_active_text_color};
                    }

                    {$ays_faq_display_all_style}
                ";

        $faq_view .= "</style>";

    
        if(isset($options["collapseStyle"]))
        {
            $collapseStyle = $options["collapseStyle"];
        }
        else{
            $collapseStyle = "none";
        }

        switch($collapseStyle){
            case "none":
                $faq_CollapseStyle = "noneCollapse";
                break;
            case "accordion";
                $faq_CollapseStyle = "accordionFAQ";
                break;
        }

        $questions_numbering = $this->ays_question_numbering($show_question_numbering);
        $faq_sendQuestionToAdmin = "";
        if(isset($options["sendQuestionToAdmin"]) && $options["sendQuestionToAdmin"] == "on") {
            $faq_sendQuestionToAdmin = "<div class='ays-add-question'>
                <form action='post'>
                    <input type='text' class='ays-add-question-input' name='ays_add_question' placeholder='Add your question' />
                    <button type='button' class='ays-add-question-submit'>".
                __( 'Send', $this->plugin_name) . "</button>
                </form>
                <div style='display: none;' class='ays-add-question-text'>".
                __( 'Your question added', $this->plugin_name) . "</div>
            </div>";
        }
        switch($ays_faq_theme){
            case "default_arrow":
                 $faq_view .= "<div class='ays-faq ays-faq-default'>
                        <div class='ays-title ays-title-default' style=' font-size:".$ays_faq_title_font_size."px; ".$ays_faq_title_display."'>".stripcslashes(htmlentities($faq['title'])) ."</div>
                        <hr>
                        <div class='ays-description ays-description-default' style='".$ays_faq_desc_display."'>".wpautop($faq['description'])."</div>
                        <div class='ays-main' data-id='".$faq_CollapseStyle."'>";
                    foreach($faq_question_array as $key => $question){
                        if($question == ""){
                            $question = "No question";
                        }
                        if( ! empty( $questions_numbering ) ){
                            $numebering_question = $questions_numbering[$key] . ' ';
                        }else{
                            $numebering_question = '';
                        }
                       $faq_view .= "<div class='ays-border-default ays-faq-question-border' id='question_block_".$key."'>
                                        <div class='ays-question ays-question-default' style='min-height:".$faq_ans_height.";display:grid;align-items:center;'>
                                            <div class='ays-sub-question'>
                                                <label class='ays_faq_label'>{$numebering_question}".stripcslashes(htmlentities( $question ))."</label>
                                            </div>
                                        </div>
                                        <div class='ays-answer ays-answer-default'>
                                            <div class='ays_modal_element' style='font-size:".$ays_faq_ans_font_size."px'>".wpautop(stripcslashes( $this->ays_autoembed($faq_answer_array[$key]) ))."</div>
                                        </div>
                                    </div>";
                    }
                $faq_view .= $faq_sendQuestionToAdmin."</div></div>";
                break;
            case "plusminus":
                $faq_view .= "<div class='ays-faq ays-faq-plusminus'>
                        <div class='ays-title ays-title-plusminus' style=' font-size:".$ays_faq_title_font_size."px;" .$ays_faq_title_display."'>".stripcslashes(htmlentities( $faq['title'] ))."</div>
                        <div class='ays-description ays-description-plusminus' style='".$ays_faq_desc_display."'>".wpautop( $faq['description'] )."</div>
                        <div class='ays-main' data-id='".$faq_CollapseStyle."'>";
                    foreach($faq_question_array as $key => $question){
                        if($question == ""){
                            $question = "No question";
                        }
                        if( ! empty( $questions_numbering ) ){
                            $numebering_question = $questions_numbering[$key] . ' ';
                        }else{
                            $numebering_question = '';
                        }
                       $faq_view .= "<div class='ays-border-plusminus ays-border-default ays-faq-question-border' id='question_block_".$key."'>
                                        <div class='ays-question ays-question-plusminus' style='min-height:".$faq_ans_height.";display:grid;align-items:center;'>
                                            <div class='ays-sub-question'>
                                                <label class='ays_faq_label'>{$numebering_question}".stripcslashes(htmlentities( $question ))."</label>
                                            </div>
                                        </div>
                                        <div class='ays-answer ays-answer-plusminus'>
                                            <div class='ays_modal_element' style='font-size:".$ays_faq_ans_font_size."px'>".wpautop(stripcslashes( $this->ays_autoembed($faq_answer_array[$key]) ))."</div>
                                        </div>
                                    </div>";
                    }
                 $faq_view .= $faq_sendQuestionToAdmin."</div></div>";
                break;
            case "simple":
                $faq_view .= "<div class='ays-faq ays-faq-simple'>
                        <input type='hidden' value='{$ays_faq_enable_questions_border}' id='ays_faq_enable_border_simple_theme' data-id='{$faq['id']}'/>
                        <div class='ays-title ays-title-simple' style='font-size:".$ays_faq_title_font_size."px;" .$ays_faq_title_display."'>" 
                            .stripcslashes(htmlentities( $faq['title'] )).
                        "</div>
                        <div class='ays-description ays-description-simple' style='".$ays_faq_desc_display."'>".wpautop( $faq['description'] )."</div>
                        <div class='ays-main' data-id='".$faq_CollapseStyle."'>";
                    foreach($faq_question_array as $key => $question){
                        if($question == ""){
                            $question = "No question";
                        }
                        if( ! empty( $questions_numbering ) ){
                            $numebering_question = $questions_numbering[$key] . ' ';
                        }else{
                            $numebering_question = '';
                        }
                       $faq_view .= "<div class='ays-border-simple ays-border-default ays-faq-question-border' id='question_block_".$key."''>
                                    <div class='ays-question ays-question-simple' style='min-height:".$faq_ans_height.";display:grid;align-items:center;'>
                                    <div class='ays-sub-question'>
                                            <label class='ays_faq_label'>{$numebering_question}".stripcslashes(htmlentities( $question ))."</label>
                                        </div>
                                    </div>
                                    <div class='ays-answer ays-answer-simple'>
                                        <div class='ays_modal_element' style='font-size:".$ays_faq_ans_font_size."px' >".wpautop(stripcslashes( $this->ays_autoembed($faq_answer_array[$key]) ))."</div>
                                    </div>
                                </div>";
                    }
                $faq_view .= $faq_sendQuestionToAdmin."</div></div>";
                break;
        }
        $faq_view .= "</div>";

        echo $faq_view;
        return str_replace(array("\r\n", "\n", "\r"), "\n", ob_get_clean());
    }
    
    public function ays_get_faq_by_id( $id ) {
	    global $wpdb;

        $sql = "SELECT * FROM {$wpdb->prefix}ays_faqs WHERE id=" . absint( intval( $id ) );

        $result = $wpdb->get_row($sql, 'ARRAY_A');
        if( ! is_null( $result ) ) {
            $json = $result['style'];
            $result['style'] = json_decode($json, true);
            $json = $result['options'];
            $result['options'] = json_decode($json, true);
    
            return $result;
        }
        return false;
    }
    
    public function ays_get_user_information() {
        if(isset($_REQUEST['userQuestion']) && !empty($_REQUEST['userQuestion'])) {
            global $wpdb;
            $userId = intval($_REQUEST['userId']);
            $results_table = $wpdb->prefix . 'ays_faqs';

            $sql = "SELECT user_question FROM $results_table WHERE id = $userId";
            $question_res = $wpdb->get_var($sql);

            if($question_res == null){
                $user_update_question = stripslashes($_REQUEST["userQuestion"]);
            } else {
                $user_update_question = $question_res."****".stripslashes($_REQUEST["userQuestion"]);
            }
            $results = $wpdb->update(
                $results_table,
                array( 'user_question' => $user_update_question ),
                array( 'id' => $userId ),
                array( '%s' ),
                array( '%d' )
            );
        }

        if(is_user_logged_in()) {
            $output = json_encode(wp_get_current_user());
        } else {
            $output = 'null';
        }
        echo $output;
        wp_die();
    }

    public static function ays_question_numbering( $numbering ){
        $keyword_arr = array();
        switch ($numbering) {
            case '1.':

                $char_min_val = '1';
                $char_max_val = '100';
                for($x = $char_min_val; $x <= $char_max_val; $x++){
                    $keyword_arr[] = $x .".";
                }

                break;
            case '1)':

                $char_min_val = '1';
                $char_max_val = '100';
                for($x = $char_min_val; $x <= $char_max_val; $x++){
                    $keyword_arr[] = $x .")";
                }

                break;
            case 'A.':

                $char_min_val = 'A';
                $char_max_val = 'Z';
                for($x = $char_min_val; $x <= $char_max_val; $x++){
                    $keyword_arr[] = $x .".";
                }

                break;
            case 'A)':

                $char_min_val = 'A';
                $char_max_val = 'Z';
                for($x = $char_min_val; $x <= $char_max_val; $x++){
                    $keyword_arr[] = $x .")";
                }

                break;
            case 'a.':
                $char_min_val = 'a';
                $char_max_val = 'z';
                for($x = $char_min_val; $x <= $char_max_val; $x++){
                    $keyword_arr[] = $x .".";
                }

                break;
            case 'a)':

                $char_min_val = 'a';
                $char_max_val = 'z';
                for($x = $char_min_val; $x <= $char_max_val; $x++){
                    $keyword_arr[] = $x .")";
                }

                break;

            default:

                break;
        }

        return $keyword_arr;
    }
    
}

